/**
 * This program has been developed by students from the bachelor Computer Science at
 * Utrecht University within the Software Project course.
 * © Copyright Utrecht University (Department of Information and Computing Sciences)
 */

/* istanbul ignore file */
/* The comment above was added so the code coverage wouldn't count this file towards code coverage.
 * We do not test components/renderfunctions/styling files.
 * See testing plan for more details.*/
import React, { useState } from 'react';
import { TextField, Button, NativeSelect } from '@mui/material';
import styles from './add-database-form.module.scss';
import {
  AddDatabaseRequest,
  DatabaseType,
  databaseNameMapping,
} from '@graphpolaris/shared/lib/data-access';

/** AddDatabaseFormProps is an interface containing the AuthViewModel. */
export interface AddDatabaseFormProps {
  open: boolean;
  onClose(): void;
  onSubmit(data: AddDatabaseRequest): void;
}

/** AddDatabaseFormState is an interface containing the databasehost information. */
export interface AddDatabaseFormState extends AddDatabaseRequest {
  // username: string;
  // password: string;
  // hostname: string;
  // port: number;
  // databaseName: string;
  // internalDatabase: string;
  // databaseType: string;
  // styles: Record<string, string>; // TODO: check if needed
}

/** AddDatabaseForm is the View implementation for the connect screen that will be rendered. */
export default function AddDatabaseForm(props: AddDatabaseFormProps) {
  const [state, setState] = useState<AddDatabaseFormState>({
    username: 'root',
    password: 'DikkeDraak',
    url: 'https://datastrophe.science.uu.nl/',
    port: 8529,
    name: 'Tweede Kamer Dataset',
    internal_database_name: 'TweedeKamer',
    // styles: props.styles, // FIXME
    type: DatabaseType.ArangoDB,
  });

  /**
   * Validates if the port value is numerical. Only then will the state be updated.
   * @param port The new port value.
   */
  function handlePortChanged(port: string): void {
    if (!isNaN(Number(port))) setState({ ...state, port: Number(port) });
  }

  /** Handles the submit button click. Calls the onSubmit in the props with all the fields. */
  function handleSubmitClicked(): void {
    props.onSubmit(state);
  }

  return props.open ? (
    <div
      className={styles.wrapper}
      onMouseDown={() => {
        props.onClose();
      }}
    >
      <div
        className={styles.authWrapper}
        onMouseDown={(e) => {
          e.stopPropagation();
        }}
      >
        <h1 className={styles.header}>Database Connect</h1>
        <form
          className={styles.formWrapper}
          onSubmit={(event: React.FormEvent) => {
            event.preventDefault();
            handleSubmitClicked();
          }}
        >
          <div className={styles.loginContainer}>
            <TextField
              className={styles.passLabel}
              label="Database name"
              type="databaseName"
              value={state.name}
              onChange={(event) =>
                setState({
                  ...state,
                  name: event.currentTarget.value,
                })
              }
              required
            />
          </div>
          <div className={styles.loginContainer}>
            <NativeSelect
              className={styles.passLabel}
              value={databaseNameMapping[state.type]}
              onChange={(event) => {
                setState({
                  ...state,
                  type: databaseNameMapping.indexOf(event.currentTarget.value),
                });
              }}
            >
              {databaseNameMapping.map((dbName) => (
                <option value={dbName} key={dbName}>
                  {dbName}
                </option>
              ))}
            </NativeSelect>
          </div>
          <div className={styles.loginContainerRow}>
            <TextField
              className={styles.hostLabel}
              label="Hostname/IP"
              type="hostname"
              value={state.url}
              onChange={(event) =>
                setState({
                  ...state,
                  url: event.currentTarget.value,
                })
              }
              required
            />
            <TextField
              className={styles.portLabel}
              label="Port"
              type="port"
              value={state.port}
              onChange={(event) => handlePortChanged(event.currentTarget.value)}
              required
            />
          </div>
          <div className={styles.loginContainer}>
            <TextField
              className={styles.userLabel}
              label="Username"
              type="username"
              value={state.username}
              onChange={(event) =>
                setState({
                  ...state,
                  username: event.currentTarget.value,
                })
              }
              required
            />
          </div>
          <div className={styles.loginContainer}>
            <TextField
              className={styles.passLabel}
              label="Password"
              type="password"
              value={state.password}
              onChange={(event) =>
                setState({
                  ...state,
                  password: event.currentTarget.value,
                })
              }
              required
            />
          </div>
          <div className={styles.loginContainer}>
            <TextField
              className={styles.passLabel}
              label="Internal database"
              type="internalDatabaseName"
              value={state.internal_database_name}
              onChange={(event) =>
                setState({
                  ...state,
                  internal_database_name: event.currentTarget.value,
                })
              }
              required
            />
          </div>
          <div className={styles.loginContainerButton}>
            <Button variant="outlined" type="submit">
              Submit
            </Button>
            <Button
              className={styles.cancelButton}
              variant="outlined"
              onClick={() => {
                props.onClose();
              }}
            >
              Cancel
            </Button>
          </div>
        </form>
      </div>
    </div>
  ) : (
    <></>
  );
}
