import { TypedUseSelectorHook, useDispatch, useSelector } from 'react-redux';
import { selectGraphQueryResult } from './graphQueryResultSlice';
import {
  schemaGraph,
  schemaGraphology,
  selectSchemaLayout,
} from './schemaSlice';
import type { RootState, AppDispatch } from './store';
import { configState } from '@graphpolaris/shared/lib/data-access/store/configSlice';
import {
  selectQuerybuilderGraph,
  selectQuerybuilderGraphology,
  selectQuerybuilderHash,
} from '@graphpolaris/shared/lib/data-access/store/querybuilderSlice';
import { sessionCacheState } from './sessionSlice';
import { authState } from './authSlice';

// Use throughout your app instead of plain `useDispatch` and `useSelector`
export const useAppDispatch: () => AppDispatch = useDispatch;
// export const useAppDispatch = () => useDispatch<AppDispatch>();
export const useAppSelector: TypedUseSelectorHook<RootState> = useSelector;

/** Gives the graphQueryResult from the store */
export const useGraphQueryResult = () => useAppSelector(selectGraphQueryResult);

// Gives the schema form the store (as a graphology object)
export const useSchemaGraphology = () => useAppSelector(schemaGraphology);
export const useSchemaGraph = () => useAppSelector(schemaGraph);

// Gives the schema form the store (as a graphology object)
export const useSchemaLayout = () => useAppSelector(selectSchemaLayout);
export const useQuerybuilderGraphology = () =>
  useAppSelector(selectQuerybuilderGraphology);
export const useQuerybuilderGraph = () =>
  useAppSelector(selectQuerybuilderGraph);
export const useQuerybuilderHash = () =>
  useAppSelector(selectQuerybuilderHash);

// Overall Configuration of the app
export const useConfig = () => useAppSelector(configState);
export const useSessionCache = () => useAppSelector(sessionCacheState);
export const useAuthorizationCache = () => useAppSelector(authState);
